Extensible : Custom Calendar Views

# Custom Calendar Views

This example shows how you can create custom views using standard configs. The default event color has also been customized by overriding a few CSS rules (view source to see that). The CalendarPanel contains the following views:

- 3 Days: Using only `showMultiDayView:true` we can get a multi-day view
- Work Week: This view shows how you could create a work week view that is Monday-Friday, and only business hours. This uses many different options for customizing the view including altering the row heights, providing 10-minute drag increments, restricting the start and end times of the view, etc. See the source for complete details.
- 3 Weeks: A multi-week view with a custom `weekCount`

View the source